#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Alerts on inside bars
	/// 
	/// Code Written by Tyler Moore
	/// www.FreeIndicators.Com
	/// 
	/// For modifications to this code or to have your own custom code written
	/// please visit www.MooreTechLLC.com	
    /// </summary>
   [Description("Inside Bar Alerts\n\nwww.FreeIndicators.com")]
    public class InsideBarAlerts : Indicator
    {
        #region Variables
        // Wizard generated variables
        private string alertFile = @"Alert1.wav"; // Default setting for AlertFile
		private Color alertBarColor = Color.Blue;
        // User defined variables (add any user defined variables below)
        #endregion

        protected override void Initialize()
        {
            Overlay				= true;
        }

        protected override void OnBarUpdate()
        {
            if (CurrentBar<1)
				return;
			
			bool highOK = High[0]<High[1];
			bool lowOK = Low[0]>Low[1];
			bool insideBar = highOK && lowOK;
			if (insideBar)
			{
				BarColor = alertBarColor;
				PlaySound(alertFile);
			}
        }

        #region Properties

        [Description("")]
        [GridCategory("Parameters")]
        public string AlertFile
        {
            get { return alertFile; }
            set { alertFile = value; }
        }
		
		[XmlIgnore()]
		[Description("")]
		[GridCategory("Parameters")]		
		public Color AlertBarColor
		{
			get { return alertBarColor; }
			set { alertBarColor = value; }
		}
		
		[Browsable(false)]
		public string AlertBarColorS
		{
			get { return NinjaTrader.Gui.Design.SerializableColor.ToString(alertBarColor); }
			set { alertBarColor = NinjaTrader.Gui.Design.SerializableColor.FromString(value); }
		}
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private InsideBarAlerts[] cacheInsideBarAlerts = null;

        private static InsideBarAlerts checkInsideBarAlerts = new InsideBarAlerts();

        /// <summary>
        /// Inside Bar Alerts\n\nwww.FreeIndicators.com
        /// </summary>
        /// <returns></returns>
        public InsideBarAlerts InsideBarAlerts(Color alertBarColor, string alertFile)
        {
            return InsideBarAlerts(Input, alertBarColor, alertFile);
        }

        /// <summary>
        /// Inside Bar Alerts\n\nwww.FreeIndicators.com
        /// </summary>
        /// <returns></returns>
        public InsideBarAlerts InsideBarAlerts(Data.IDataSeries input, Color alertBarColor, string alertFile)
        {
            if (cacheInsideBarAlerts != null)
                for (int idx = 0; idx < cacheInsideBarAlerts.Length; idx++)
                    if (cacheInsideBarAlerts[idx].AlertBarColor == alertBarColor && cacheInsideBarAlerts[idx].AlertFile == alertFile && cacheInsideBarAlerts[idx].EqualsInput(input))
                        return cacheInsideBarAlerts[idx];

            lock (checkInsideBarAlerts)
            {
                checkInsideBarAlerts.AlertBarColor = alertBarColor;
                alertBarColor = checkInsideBarAlerts.AlertBarColor;
                checkInsideBarAlerts.AlertFile = alertFile;
                alertFile = checkInsideBarAlerts.AlertFile;

                if (cacheInsideBarAlerts != null)
                    for (int idx = 0; idx < cacheInsideBarAlerts.Length; idx++)
                        if (cacheInsideBarAlerts[idx].AlertBarColor == alertBarColor && cacheInsideBarAlerts[idx].AlertFile == alertFile && cacheInsideBarAlerts[idx].EqualsInput(input))
                            return cacheInsideBarAlerts[idx];

                InsideBarAlerts indicator = new InsideBarAlerts();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                indicator.AlertBarColor = alertBarColor;
                indicator.AlertFile = alertFile;
                Indicators.Add(indicator);
                indicator.SetUp();

                InsideBarAlerts[] tmp = new InsideBarAlerts[cacheInsideBarAlerts == null ? 1 : cacheInsideBarAlerts.Length + 1];
                if (cacheInsideBarAlerts != null)
                    cacheInsideBarAlerts.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheInsideBarAlerts = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Inside Bar Alerts\n\nwww.FreeIndicators.com
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.InsideBarAlerts InsideBarAlerts(Color alertBarColor, string alertFile)
        {
            return _indicator.InsideBarAlerts(Input, alertBarColor, alertFile);
        }

        /// <summary>
        /// Inside Bar Alerts\n\nwww.FreeIndicators.com
        /// </summary>
        /// <returns></returns>
        public Indicator.InsideBarAlerts InsideBarAlerts(Data.IDataSeries input, Color alertBarColor, string alertFile)
        {
            return _indicator.InsideBarAlerts(input, alertBarColor, alertFile);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Inside Bar Alerts\n\nwww.FreeIndicators.com
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.InsideBarAlerts InsideBarAlerts(Color alertBarColor, string alertFile)
        {
            return _indicator.InsideBarAlerts(Input, alertBarColor, alertFile);
        }

        /// <summary>
        /// Inside Bar Alerts\n\nwww.FreeIndicators.com
        /// </summary>
        /// <returns></returns>
        public Indicator.InsideBarAlerts InsideBarAlerts(Data.IDataSeries input, Color alertBarColor, string alertFile)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.InsideBarAlerts(input, alertBarColor, alertFile);
        }
    }
}
#endregion
